@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$MooseX::MungeHas::AUTHORITY = 'cpan:TOBYINK';
-	$MooseX::MungeHas::VERSION   = '0.007';
+	$MooseX::MungeHas::VERSION   = '0.008';
 };
 
 use Carp qw(croak);
@@ -257,7 +257,7 @@ sub _make_has
 				local %_ = %spec;
 				local $_ = $attr;
 				$coderef->($attr, %_);
-				return $orig->($attr, %_);
+				$orig->($attr, %_);
 			}
 		}
 		else
@@ -489,7 +489,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
